@@ -43,8 +43,9 @@ from phonopy.units import Bohr
 from phonopy.cui.settings import fracval
 from phonopy.structure.atoms import PhonopyAtoms as Atoms
 from phonopy.structure.atoms import symbol_map
-from phonopy.structure.cells import get_supercell
-from phonopy.harmonic.force_constants import distribute_force_constants
+from phonopy.structure.cells import get_supercell, get_primitive
+from phonopy.harmonic.dynmat_to_fc import (
+    distribute_force_constants_by_translations)
 
 def parse_set_of_forces(num_atoms,
                         forces_filenames,
@@ -336,15 +337,20 @@ class PH_Q2R(object):
     ---------
     #!/usr/bin/env python
 
-    from phonopy.file_IO import write_FORCE_CONSTANTS
-    from phonopy.interface.qe import read_pwscf, PH_Q2R
-
     cell, _ = read_pwscf(primcell_filename)
     q2r = PH_Q2R(q2r_filename)
     q2r.run(cell)
-    write_FORCE_CONSTANTS(q2r.fc)
+    q2r.write_force_constants()
     ---------
 
+    To save memory/storage space of force constants, the shape of
+    force constants array is (n_uatom, n_satom, 3, 3), where u_atom is
+    the number of atoms in unit cell and n_satom is the number of
+    atoms in super cell, i.e., u_atom * prod(dim). When using this
+    force constants data from phonopy with primitive cell that is
+    differnt from unit cell, force constants have to be regenerated
+    for the primitive cell, which is not done in this class.
+
     Treatment of non-analytical term correction (NAC) is different
     between phonopy and QE. For insulator, QE automatically calculate
     dielectric constant and Born effective charges at PH calculation
@@ -362,6 +368,30 @@ class PH_Q2R(object):
     effective charges data. So it is possible to replace the Gamma
     point file by this Gamma point only file to run q2r.x for phonopy.
 
+    Attributes
+    ----------
+    fc : ndarray
+        Force constants in either compact or full matrix.
+        dtype='double'
+        shape=(natom_prim, natom_super, 3, 3) for compact fc or
+              (natom_super, natom_super, 3, 3) for full fc
+    dimenstion : ndarray
+        Supercell dimensions (not matrix)
+        dtype='intc'
+        shape=(3,)
+    epsilon : ndarray
+        Dielectric constant tensor
+        dtype='double'
+        shape=(3, 3)
+    born : ndarray
+        Born effective charges
+        dtype='double'
+        shape=(natom_prim, 3, 3)
+    primitive : Primitive
+        Primitive cell
+    supercell : Supercell
+        Supercell
+
     """
 
     def __init__(self, filename, symprec=1e-5):
@@ -369,14 +399,30 @@ class PH_Q2R(object):
         self.dimension = None
         self.epsilon = None
         self.borns = None
+        self.primitive = None
+        self.supercell = None
         self._symprec = symprec
         self._filename = filename
 
-    def run(self, cell, parse_fc=True):
-        """Run making supercell force constants readable for phonopy
+    def run(self, cell, is_full_fc=False, parse_fc=True):
+        """Make supercell force constants readable for phonopy
 
-        Args:
-            cell(Atoms): Primitive cell used for QE/PH calculation
+        Note
+        ----
+        Born effective charges and dielectric constant tensor are read from
+        QE output file if they exist. But this means dipole-dipole contributions
+        are removed from force constants and this force constants matrix is not
+        usable in phonopy.
+
+        Arguments
+        ---------
+        cell : PhonopyAtoms
+            Primitive cell used for QE/PH calculation.
+        is_full_fc : Bool, optional, default=False
+            Whether to create full or compact force constants.
+        parse_fc : Bool, optional, default=True
+            Force constants file of QE is not parsed when this is False.
+            False may be used when expected to parse only epsilon and born.
 
         """
 
@@ -386,7 +432,18 @@ class PH_Q2R(object):
             self.epsilon = fc_dct['dielectric']
             self.borns = fc_dct['born']
             if parse_fc:
-                self.fc = self._arrange_supercell_fc(cell, fc_dct['fc'])
+                (self.fc,
+                 self.primitive,
+                 self.supercell) = self._arrange_supercell_fc(
+                     cell, fc_dct['fc'], is_full_fc=is_full_fc)
+
+    def write_force_constants(self, fc_format='hdf5'):
+        if self.fc is not None:
+            if fc_format == 'hdf5':
+                p2s_map = self.primitive.get_primitive_to_supercell_map()
+                write_force_constants_to_hdf5(self.fc, p2s_map=p2s_map)
+            else:
+                write_FORCE_CONSTANTS(self.fc)
 
     def _parse_q2r(self, f):
         """Parse q2r output file
@@ -421,7 +478,7 @@ class PH_Q2R(object):
             epsilon = None
             borns = None
         line = f.readline()
-        dim = tuple(int(x) for x in line.split())
+        dim = np.array([int(x) for x in line.split()], dtype='intc')
 
         return natom, dim, epsilon, borns
 
@@ -455,32 +512,43 @@ class PH_Q2R(object):
                 fc[j, i * ndim + i_dim, l, k] = float(line.split()[3])
         return fc
 
-    def _arrange_supercell_fc(self, cell, q2r_fc):
+    def _arrange_supercell_fc(self, cell, q2r_fc, is_full_fc=False):
         dim = self.dimension
         q2r_spos = self._get_q2r_positions(cell)
         scell = get_supercell(cell, np.diag(dim))
+        pcell = get_primitive(scell, np.diag(1.0 / dim))
+
+        diff = cell.get_scaled_positions() - pcell.get_scaled_positions()
+        diff -= np.rint(diff)
+        assert (np.abs(diff) < 1e-8).all()
         assert scell.get_number_of_atoms() == len(q2r_spos)
+
         site_map = self._get_site_mapping(scell.get_scaled_positions(),
                                           q2r_spos,
                                           scell.get_cell())
-        natom = cell.get_number_of_atoms()
+        natom = pcell.get_number_of_atoms()
         ndim = np.prod(dim)
         natom_s = natom * ndim
-        s_indices = [np.where(site_map==(i * ndim))[0][0] for i in range(natom)]
-        fc = np.zeros((natom_s, natom_s, 3, 3), dtype='double', order='C')
 
-        for i, si in enumerate(s_indices):
-            fc[si, :] = q2r_fc[i, site_map]
+        if is_full_fc:
+            fc = np.zeros((natom_s, natom_s, 3, 3), dtype='double', order='C')
+            p2s = pcell.get_primitive_to_supercell_map()
+            fc[p2s, :] = q2r_fc[:, site_map]
+            distribute_force_constants_by_translations(fc,
+                                                       pcell,
+                                                       scell)
+        else:
+            fc = np.zeros((natom, natom_s, 3, 3), dtype='double', order='C')
+            fc[:, :] = q2r_fc[:, site_map]
 
-        self._distribute_fc2(fc, s_indices, scell)
-        return fc
+        return fc, pcell, scell
 
     def _get_q2r_positions(self, cell):
         dim = self.dimension
         natom = cell.get_number_of_atoms()
         ndim = np.prod(dim)
         spos = np.zeros((natom * np.prod(dim), 3), dtype='double', order='C')
-        trans = [x[::-1] for x in np.ndindex(dim[::-1])]
+        trans = [x[::-1] for x in np.ndindex(tuple(dim[::-1]))]
         for i, p in enumerate(cell.get_scaled_positions()):
             spos[i * ndim:(i + 1) * ndim] = (trans + p) / dim
         return spos
@@ -498,23 +566,3 @@ class PH_Q2R(object):
         assert len(np.unique(site_map)) == len(spos)
 
         return np.array(site_map)
-
-    def _distribute_fc2(self, fc, s_indices, scell):
-        dim = self.dimension
-        t = np.zeros((np.prod(dim), 3), dtype='double', order='C')
-        r = np.zeros((np.prod(dim), 3, 3), dtype='intc', order='C')
-
-        for i, (d3, d2, d1) in enumerate(np.ndindex(dim[::-1])):
-            r[i] = np.identity(3, dtype='intc')
-            t[i] = np.array([d1, d2, d3], dtype='double') / dim
-
-        natom_s = scell.get_number_of_atoms()
-        lattice = np.array(scell.get_cell().T, dtype='double', order='C')
-        distribute_force_constants(fc,
-                                   np.arange(natom_s),
-                                   s_indices,
-                                   lattice,
-                                   scell.get_scaled_positions(),
-                                   r,
-                                   t,
-                                   self._symprec)
