@@ -62,8 +62,16 @@ character_table = {
                                ( 0, 0,-1 )),)}}],
 
     # C2 (3)
-    '2': None,
-
+    '2':
+    [{'rotation_list': ('E', 'C2'),
+      'character_table': {'A' : (1, 1),
+                          'B' : (1, -1)},
+      'mapping_table': {'E' : ((( 1, 0, 0 ),
+                                ( 0, 1, 0 ),
+                                ( 0, 0, 1 )),),
+                        'C2': (((-1, 0, 0 ),
+                                ( 0, 1, 0 ),
+                                ( 0, 0,-1 )),)}}],
     # C1v = Cs = C1h (4)
     'm':
     [{'rotation_list': ('E', 'sgh'),
@@ -207,7 +215,7 @@ character_table = {
                         'S4': ((( 0, 1, 0 ),
                                 (-1, 0, 0 ),
                                 ( 0, 0,-1 )),
-		               (( 0,-1, 0 ),
+                               (( 0,-1, 0 ),
                                 ( 1, 0, 0 ),
                                 ( 0, 0,-1 )),)}}],
 
@@ -238,7 +246,7 @@ character_table = {
                         'S4' : ((( 0, 1, 0 ),
                                  (-1, 0, 0 ),
                                  ( 0, 0, -1 ),),
-		                (( 0,-1, 0 ),
+                                (( 0,-1, 0 ),
                                  ( 1, 0, 0 ),
                                  ( 0, 0,-1 )),),
                         'sgh': ((( 1, 0, 0 ),
@@ -325,7 +333,7 @@ character_table = {
                         'S4'  : ((( 0, 1, 0 ),
                                   (-1, 0, 0 ),
                                   ( 0, 0,-1 )),
-		                 (( 0,-1, 0 ),
+                                 (( 0,-1, 0 ),
                                   ( 1, 0, 0 ),
                                   ( 0, 0,-1 )),),
                         'C2z' : (((-1, 0, 0 ),
@@ -355,7 +363,7 @@ character_table = {
                         'S4'    : ((( 0, 1, 0 ),
                                     (-1, 0, 0 ),
                                     ( 0, 0,-1 )),
-		                   (( 0,-1, 0 ),
+                                   (( 0,-1, 0 ),
                                     ( 1, 0, 0 ),
                                     ( 0, 0,-1 )),),
                         'C2z'   : (((-1, 0, 0 ),
@@ -504,7 +512,29 @@ character_table = {
                                   ( 0, 0,-1 )),)}}],
 
     # C3v (19)
-    '3m': None,
+    '3m':
+    [{'rotation_list': ('E', 'C3', 'sgv'),
+      'character_table': {'A1': (1, 1, 1),
+                          'A2': (1, 1,-1),
+                          'E' : (2,-1, 0)},
+      'mapping_table': {'E'   : ((( 1, 0, 0),
+                                  ( 0, 1, 0),
+                                  ( 0, 0, 1)),),
+                        'C3'  : ((( 0,-1, 0),
+                                  ( 1,-1, 0),
+                                  ( 0, 0, 1)),
+                                 ((-1, 1, 0),
+                                  (-1, 0, 0),
+                                  ( 0, 0, 1)),),
+                        'sgv' : ((( 0,-1, 0),
+                                  (-1, 0, 0),
+                                  ( 0, 0, 1)),
+                                 ((-1, 1, 0),
+                                  ( 0, 1, 0),
+                                  ( 0, 0, 1)),
+                                 (( 1, 0, 0),
+                                  ( 1,-1, 0),
+                                  ( 0, 0, 1)),)}}],
 
     # D3d (20)
     '-3m':
@@ -553,10 +583,56 @@ character_table = {
                                   ( 0, 0, 1 )),)}}],
 
     # C6 (21)
-    '6': None,
+    '6':
+    [{'rotation_list': ('E', 'C6', 'C3', 'C2'),
+      'character_table': {'A' : ( 1, 1, 1, 1),
+                          'B' : ( 1,-1, 1,-1),
+                          'E1': ( 2, 1,-1,-2),
+                          'E2': ( 2,-1,-1, 2)},
+      'mapping_table': {'E'  : ((( 1, 0, 0),
+                                 ( 0, 1, 0),
+                                 ( 0, 0, 1)),),
+                        'C6' : ((( 1,-1, 0),
+                                 ( 1, 0, 0),
+                                 ( 0, 0, 1)),
+                                (( 0, 1, 0),
+                                 (-1, 1, 0),
+                                 ( 0, 0, 1)),),
+                        'C3' : ((( 0,-1, 0),
+                                 ( 1,-1, 0),
+                                 ( 0, 0, 1)),
+                                ((-1, 1, 0),
+                                 (-1, 0, 0),
+                                 ( 0, 0, 1)),),
+                        'C2' : (((-1, 0, 0),
+                                 ( 0,-1, 0),
+                                 ( 0, 0, 1)),)}}],
 
     # C3h (22)
-    '-6': None,
+    '-6':
+    [{'rotation_list': ('E', 'C3', 'sgh', 'S3'),
+      'character_table': {'A\''   : ( 1, 1, 1, 1),
+                          'E\''   : ( 2,-1, 2,-1),
+                          'A\'\'' : ( 1, 1,-1,-1),
+                          'E\'\'' : ( 2,-1,-2, 1)},
+      'mapping_table': {'E'  : ((( 1, 0, 0),
+                                 ( 0, 1, 0),
+                                 ( 0, 0, 1)),),
+                        'C3' : ((( 0,-1, 0),
+                                 ( 1,-1, 0),
+                                 ( 0, 0, 1)),
+                                ((-1, 1, 0),
+                                 (-1, 0, 0),
+                                 ( 0, 0, 1)),),
+                        'sgh' : ((( 1, 0, 0),
+                                  ( 0, 1, 0),
+                                  ( 0, 0,-1)),),
+                        'S3'  : (((-1, 1, 0),
+                                  (-1, 0, 0),
+                                  ( 0, 0,-1)),
+                                 (( 0,-1, 0),
+                                  ( 1,-1, 0),
+                                  ( 0, 0,-1)),)}}],
 
     # C6h (23)
     '6/m':
@@ -607,7 +683,50 @@ character_table = {
                                     ( 0, 0,-1 )),)}}],
 
     # D6 (24)
-    '622': None,
+    '622':
+    [{'rotation_list': ('E', 'C6', 'C3', 'C2', 'C2\'', 'C2\'\''),
+      'character_table': {'A1' : ( 1, 1, 1, 1, 1, 1),
+                          'A2' : ( 1, 1, 1, 1,-1,-1),
+                          'B1' : ( 1,-1, 1,-1, 1,-1),
+                          'B2' : ( 1,-1, 1,-1,-1, 1),
+                          'E1' : ( 2, 1,-1,-2, 0, 0),
+                          'E2' : ( 2,-1,-1, 2, 0, 0)},
+      'mapping_table': { 'E'      : ((( 1, 0, 0),
+                                      ( 0, 1, 0),
+                                      ( 0, 0, 1)),),
+                         'C6'     : ((( 1,-1, 0),
+                                      ( 1, 0, 0),
+                                      ( 0, 0, 1)),
+                                     (( 0, 1, 0),
+                                      (-1, 1, 0),
+                                      ( 0, 0, 1)),),
+                         'C3'     : ((( 0,-1, 0),
+                                      ( 1,-1, 0),
+                                      ( 0, 0, 1)),
+                                     ((-1, 1, 0),
+                                      (-1, 0, 0),
+                                      ( 0, 0, 1)),),
+                         'C2'     : (((-1, 0, 0),
+                                      ( 0,-1, 0),
+                                      ( 0, 0, 1)),),
+                         'C2\''   : ((( 0, 1, 0),
+                                      ( 1, 0, 0),
+                                      ( 0, 0,-1)),
+                                     (( 1,-1, 0),
+                                      ( 0,-1, 0),
+                                      ( 0, 0,-1)),
+                                     ((-1, 0, 0),
+                                      (-1, 1, 0),
+                                      ( 0, 0,-1)),),
+                         'C2\'\'' : ((( 0,-1, 0),
+                                      (-1, 0, 0),
+                                      ( 0, 0,-1)),
+                                     ((-1, 1, 0),
+                                      ( 0, 1, 0),
+                                      ( 0, 0,-1)),
+                                     (( 1, 0, 0),
+                                      ( 1,-1, 0),
+                                      ( 0, 0,-1)),)}}],
 
     # C6v (25)
     '6mm':
@@ -791,13 +910,210 @@ character_table = {
                                     ( 0, 0, 1 )),)}}],
 
     # T (28)
-    '23': None,
+    '23':
+    [{'rotation_list': ('E', 'C3', 'C2'),
+      'character_table': {'A' : (1, 1, 1),
+                          'E' : (2,-1, 2),
+                          'T' : (3, 0,-1)},
+      'mapping_table': {'E'  : ((( 1, 0, 0),
+                                 ( 0, 1, 0),
+                                 ( 0, 0, 1)),),
+                        'C3' : ((( 0, 0, 1),
+                                 ( 1, 0, 0),
+                                 ( 0, 1, 0)),
+                                (( 0, 0, 1),
+                                 (-1, 0, 0),
+                                 ( 0,-1, 0)),
+                                (( 0, 0,-1),
+                                 (-1, 0, 0),
+                                 ( 0, 1, 0)),
+                                (( 0, 0,-1),
+                                 ( 1, 0, 0),
+                                 ( 0,-1, 0)),
+                                (( 0, 1, 0),
+                                 ( 0, 0, 1),
+                                 ( 1, 0, 0)),
+                                (( 0,-1, 0),
+                                 ( 0, 0, 1),
+                                 (-1, 0, 0)),
+                                (( 0, 1, 0),
+                                 ( 0, 0,-1),
+                                 (-1, 0, 0)),
+                                (( 0,-1, 0),
+                                 ( 0, 0,-1),
+                                 ( 1, 0, 0)),),
+                        'C2' : (((-1, 0, 0),
+                                 ( 0,-1, 0),
+                                 ( 0, 0, 1)),
+                                ((-1, 0, 0),
+                                 ( 0, 1, 0),
+                                 ( 0, 0,-1)),
+                                (( 1, 0, 0),
+                                 ( 0,-1, 0),
+                                 ( 0, 0,-1)),)}}],
 
     # Th (29)
-    'm-3': None,
+    'm-3':
+    [{'rotation_list': ('E', 'C3', 'C2', 'i', 'S6', 'sgh'),
+      'character_table': {'Ag' : ( 1, 1, 1, 1, 1, 1),
+                          'Au' : ( 1, 1, 1,-1,-1,-1),
+                          'Eg' : ( 2,-1, 2, 2,-1, 2),
+                          'Eu' : ( 2,-1, 2,-2, 1,-2),
+                          'Tg' : ( 3, 0,-1, 3, 0,-1),
+                          'Tu' : ( 3, 0,-1,-3, 0, 1)},
+      'mapping_table': {'E'  : ((( 1, 0, 0),
+                                 ( 0, 1, 0),
+                                 ( 0, 0, 1)),),
+                        'C3' : ((( 0, 0, 1),
+                                 ( 1, 0, 0),
+                                 ( 0, 1, 0)),
+                                (( 0, 0, 1),
+                                 (-1, 0, 0),
+                                 ( 0,-1, 0)),
+                                (( 0, 0,-1),
+                                 (-1, 0, 0),
+                                 ( 0, 1, 0)),
+                                (( 0, 0,-1),
+                                 ( 1, 0, 0),
+                                 ( 0,-1, 0)),
+                                (( 0, 1, 0),
+                                 ( 0, 0, 1),
+                                 ( 1, 0, 0)),
+                                (( 0,-1, 0),
+                                 ( 0, 0, 1),
+                                 (-1, 0, 0)),
+                                (( 0, 1, 0),
+                                 ( 0, 0,-1),
+                                 (-1, 0, 0)),
+                                (( 0,-1, 0),
+                                 ( 0, 0,-1),
+                                 ( 1, 0, 0)),),
+                        'C2' : (((-1, 0, 0),
+                                 ( 0,-1, 0),
+                                 ( 0, 0, 1)),
+                                ((-1, 0, 0),
+                                 ( 0, 1, 0),
+                                 ( 0, 0,-1)),
+                                (( 1, 0, 0),
+                                 ( 0,-1, 0),
+                                 ( 0, 0,-1)),),
+                        'i'  : (((-1, 0, 0),
+                                 ( 0,-1, 0),
+                                 ( 0, 0,-1)),),
+                        'S6' : ((( 0, 0,-1),
+                                 (-1, 0, 0),
+                                 ( 0,-1, 0)),
+                                (( 0, 0,-1),
+                                 ( 1, 0, 0),
+                                 ( 0, 1, 0)),
+                                (( 0, 0, 1),
+                                 ( 1, 0, 0),
+                                 ( 0,-1, 0)),
+                                (( 0, 0, 1),
+                                 (-1, 0, 0),
+                                 ( 0, 1, 0)),
+                                (( 0,-1, 0),
+                                 ( 0, 0,-1),
+                                 (-1, 0, 0)),
+                                (( 0, 1, 0),
+                                 ( 0, 0,-1),
+                                 ( 1, 0, 0)),
+                                (( 0,-1, 0),
+                                 ( 0, 0, 1),
+                                 ( 1, 0, 0)),
+                                (( 0, 1, 0),
+                                 ( 0, 0, 1),
+                                 (-1, 0, 0)),),
+                        'sgh': ((( 1, 0, 0),
+                                 ( 0, 1, 0),
+                                 ( 0, 0,-1)),
+                                (( 1, 0, 0),
+                                 ( 0,-1, 0),
+                                 ( 0, 0, 1)),
+                                ((-1, 0, 0),
+                                 ( 0, 1, 0),
+                                 ( 0, 0, 1)),)}}],
 
     # O (30)
-    '432': None,
+    '432':
+    [{'rotation_list': ('E', 'C4', 'C2', 'C3', 'C2\''),
+      'character_table': {'A1' : ( 1, 1, 1, 1, 1),
+                          'A2' : ( 1,-1, 1, 1,-1),
+                          'E'  : ( 2, 0, 2,-1, 0),
+                          'T1' : ( 3, 1,-1, 0,-1),
+                          'T2' : ( 3,-1,-1, 0, 1)},
+      'mapping_table': {'E'   : ((( 1, 0, 0),
+                                  ( 0, 1, 0),
+                                  ( 0, 0, 1)),),
+                        'C4'  : ((( 0, 1, 0),
+                                  (-1, 0, 0),
+                                  ( 0, 0, 1)),
+                                 (( 0,-1, 0),
+                                  ( 1, 0, 0),
+                                  ( 0, 0, 1)),
+                                 (( 1, 0, 0),
+                                  ( 0, 0, 1),
+                                  ( 0,-1, 0)),
+                                 (( 1, 0, 0),
+                                  ( 0, 0,-1),
+                                  ( 0, 1, 0)),
+                                 (( 0, 0, 1),
+                                  ( 0, 1, 0),
+                                  (-1, 0, 0)),
+                                 (( 0, 0,-1),
+                                  ( 0, 1, 0),
+                                  ( 1, 0, 0)),),
+                        'C2'  : (((-1, 0, 0),
+                                  ( 0,-1, 0),
+                                  ( 0, 0, 1)),
+                                 ((-1, 0, 0),
+                                  ( 0, 1, 0),
+                                  ( 0, 0,-1)),
+                                 (( 1, 0, 0),
+                                  ( 0,-1, 0),
+                                  ( 0, 0,-1)),),
+                        'C3'  : ((( 0, 0, 1),
+                                  ( 1, 0, 0),
+                                  ( 0, 1, 0)),
+                                 (( 0, 0, 1),
+                                  (-1, 0, 0),
+                                  ( 0,-1, 0)),
+                                 (( 0, 0,-1),
+                                  (-1, 0, 0),
+                                  ( 0, 1, 0)),
+                                 (( 0, 0,-1),
+                                  ( 1, 0, 0),
+                                  ( 0,-1, 0)),
+                                 (( 0, 1, 0),
+                                  ( 0, 0, 1),
+                                  ( 1, 0, 0)),
+                                 (( 0,-1, 0),
+                                  ( 0, 0, 1),
+                                  (-1, 0, 0)),
+                                 (( 0, 1, 0),
+                                  ( 0, 0,-1),
+                                  (-1, 0, 0)),
+                                 (( 0,-1, 0),
+                                  ( 0, 0,-1),
+                                  ( 1, 0, 0)),),
+                        'C2\'': ((( 0,-1, 0),
+                                  (-1, 0, 0),
+                                  ( 0, 0,-1)),
+                                 (( 0, 1, 0),
+                                  ( 1, 0, 0),
+                                  ( 0, 0,-1)),
+                                 ((-1, 0, 0),
+                                  ( 0, 0, 1),
+                                  ( 0, 1, 0)),
+                                 ((-1, 0, 0),
+                                  ( 0, 0,-1),
+                                  ( 0,-1, 0)),
+                                 (( 0, 0, 1),
+                                  ( 0,-1, 0),
+                                  ( 1, 0, 0)),
+                                 (( 0, 0,-1),
+                                  ( 0,-1, 0),
+                                  (-1, 0, 0)),)}}],
 
     # Td (31)
     '-43m':
@@ -893,7 +1209,7 @@ character_table = {
                           'A2u': ( 1, 1,-1,-1, 1,-1, 1,-1,-1, 1 ),
                           'Eu' : ( 2,-1, 0, 0, 2,-2, 0, 1,-2, 0 ),
                           'T1u': ( 3, 0,-1, 1,-1,-3,-1, 0, 1, 1 ),
-                          'T2u': ( 3, 0, 1,-1,-1,-3, 1, 0, 1,-1 ) },
+                          'T2u': ( 3, 0, 1,-1,-1,-3, 1, 0, 1,-1 )},
       'mapping_table': {'E'   : ((( 1, 0, 0 ),
                                   ( 0, 1, 0 ),
                                   ( 0, 0, 1 )),),
